@@ -5,11 +5,11 @@ import subprocess
 import sys
 
 import pytest
-import six
 
 from virtualenv.discovery.py_info import PythonInfo
 from virtualenv.run import cli_run
 from virtualenv.util.path import Path
+from virtualenv.util.six import ensure_text
 
 HERE = Path(__file__).parent
 CURRENT = PythonInfo.current_system()
@@ -70,7 +70,7 @@ def zipapp_test_env(tmp_path_factory):
 def call_zipapp(zipapp, monkeypatch, tmp_path, zipapp_test_env):
     def _run(*args):
         monkeypatch.setenv(str("VIRTUALENV_OVERRIDE_APP_DATA"), str(tmp_path / "app_data"))
-        cmd = [str(zipapp_test_env), str(zipapp), "-vv", six.ensure_text(str(tmp_path / "env"))] + list(args)
+        cmd = [str(zipapp_test_env), str(zipapp), "-vv", ensure_text(str(tmp_path / "env"))] + list(args)
         subprocess.check_call(cmd)
 
     return _run
