@@ -6,11 +6,11 @@ import sys
 from uuid import uuid4
 
 import pytest
-import six
 
 from virtualenv.discovery.builtin import get_interpreter
 from virtualenv.discovery.py_info import PythonInfo
 from virtualenv.info import fs_supports_symlink
+from virtualenv.util.six import ensure_text
 
 
 @pytest.mark.skipif(not fs_supports_symlink(), reason="symlink not supported")
@@ -27,7 +27,7 @@ def test_discovery_via_path(monkeypatch, case, special_name_dir, caplog):
     exe_name = "{}{}{}".format(name, current.version_info.major, ".exe" if sys.platform == "win32" else "")
     special_name_dir.mkdir()
     executable = special_name_dir / exe_name
-    os.symlink(sys.executable, six.ensure_text(str(executable)))
+    os.symlink(sys.executable, ensure_text(str(executable)))
     new_path = os.pathsep.join([str(special_name_dir)] + os.environ.get(str("PATH"), str("")).split(os.pathsep))
     monkeypatch.setenv(str("PATH"), new_path)
     interpreter = get_interpreter(core)
